@@ -13,7 +13,7 @@ use Masterkey::Admin::Config;
 use Masterkey::Admin::Torus;
 
 our @ISA = qw();
-our $VERSION = '3.27';
+our $VERSION = '3.28';
 
 sub new {
     my $class = shift();
@@ -29,6 +29,7 @@ sub new {
 	realm => undef, authRealm => undef,
 	# ... Fall back on these otherwise
 	torus => undef, authTorus => undef,
+	fieldsWithDefaultValues => undef, # until set by first invocation
     }, $class;
 
     $this->option(logprefix => $0);
@@ -78,6 +79,19 @@ sub torus { shift()->{torus} }
 sub authTorus { shift()->{authTorus} }
 
 
+sub fieldsWithDefaultValues {
+    my $this = shift();
+
+    if (!defined $this->{fieldsWithDefaultValues}) {
+	my @candidates = $this->configObject()->configKeys("field.");
+	my @actual = grep { /^field\..*\.defaultValue/ } @candidates;
+	$this->{fieldsWithDefaultValues} = [ map { s/^field\.(.*)\.defaultValue/$1/; $_ } @actual ];
+    }
+
+    return @{ $this->{fieldsWithDefaultValues} };
+}
+
+
 sub new_with_session {
     my $class = shift();
     my($tabName, $r, $nouser) = @_;
