@@ -53,7 +53,6 @@ sub utf8param {
 
 
 # Use this instead of Data::Dumper for more compact rendering
-# Warning: unlike Data::Dumper, does NOT avoid circular referfences
 
 sub render_structure {
     my($item, $level) = @_;
@@ -67,6 +66,8 @@ sub _render_structure {
     my($item, $level, $seen, $seenCountRef) = @_;
     $level = 0 if !defined $level;
 
+    return "undef" if !defined $item;
+
     #warn "item=$item, isweak=" . (isweak($item) ? "*TRUE*" : "false");
     if (isweak($item)) {
 	return ref($item) . "(weak)";
